@@ -8,18 +8,14 @@ from fire import Fire
 from asrtoolkit.alignment import preprocess_gk_json, preprocess_txt
 from asrtoolkit.alignment.align import align
 from asrtoolkit.data_structures.time_aligned_text import time_aligned_text
-from asrtoolkit.file_utils.name_cleaners import (
-    basename,
-    sanitize,
-    strip_extension,
-)
+from asrtoolkit.file_utils.name_cleaners import basename, sanitize, strip_extension
 
 
 def align_json(ref_txt, json_file, filename=None):
     """
     CLI for forced alignment tools
-    Using a reference txt file and a hypothesis gk json 
-        file, this time-aligns the reference txt file 
+    Using a reference txt file and a hypothesis gk json
+        file, this time-aligns the reference txt file
         and outputs an STM file
     Input
       ref_txt, str - reference text file containing ground truth
