@@ -7,8 +7,10 @@ import hashlib
 import importlib
 import os
 
-from asrtoolkit.file_utils.name_cleaners import (generate_segmented_file_name,
-                                                 sanitize_hyphens)
+from asrtoolkit.file_utils.name_cleaners import (
+    generate_segmented_file_name,
+    sanitize_hyphens,
+)
 
 
 class time_aligned_text(object):
@@ -27,14 +29,17 @@ class time_aligned_text(object):
 
         >>> transcript = time_aligned_text()
         """
-        if (input_data is not None and isinstance(input_data, str)
-                and os.path.exists(input_data)):
+        if (
+            input_data is not None
+            and isinstance(input_data, str)
+            and os.path.exists(input_data)
+        ):
             self.read(input_data)
         elif input_data is not None and type(input_data) in [str, dict]:
-            self.file_extension = "txt" if isinstance(input_data,
-                                                      str) else "json"
+            self.file_extension = "txt" if isinstance(input_data, str) else "json"
             data_handler = importlib.import_module(
-                "asrtoolkit.data_handlers.{:}".format(self.file_extension))
+                "asrtoolkit.data_handlers.{:}".format(self.file_extension)
+            )
             self.segments = data_handler.read_in_memory(input_data)
 
     def hash(self):
@@ -57,7 +62,9 @@ class time_aligned_text(object):
         """
         data_handler = importlib.import_module(
             "asrtoolkit.data_handlers.{:}".format(
-                self.file_extension if self.file_extension else "txt"))
+                self.file_extension if self.file_extension else "txt"
+            )
+        )
         return "\n".join(_.__str__(data_handler) for _ in self.segments)
 
     def __add__(self, other):
@@ -80,7 +87,8 @@ class time_aligned_text(object):
         Returns unformatted text from all segments
         """
         data_handler = importlib.import_module(
-            "asrtoolkit.data_handlers.{:}".format("txt"))
+            "asrtoolkit.data_handlers.{:}".format("txt")
+        )
         return " ".join(_.__str__(data_handler) for _ in self.segments)
 
     def read(self, file_name):
@@ -88,25 +96,28 @@ class time_aligned_text(object):
         self.file_extension = file_name.split(".")[-1]
         self.location = file_name
         data_handler = importlib.import_module(
-            "asrtoolkit.data_handlers.{:}".format(self.file_extension))
+            "asrtoolkit.data_handlers.{:}".format(self.file_extension)
+        )
         self.segments = data_handler.read_file(file_name)
 
     def write(self, file_name):
         """
         Output to file using segment-specific __str__ function
         """
-        file_extension = file_name.split(
-            ".")[-1] if "." in file_name else "stm"
+        file_extension = file_name.split(".")[-1] if "." in file_name else "stm"
 
         file_name = sanitize_hyphens(file_name)
 
         data_handler = importlib.import_module(
-            "asrtoolkit.data_handlers.{:}".format(file_extension))
+            "asrtoolkit.data_handlers.{:}".format(file_extension)
+        )
         with open(file_name, "w", encoding="utf-8") as f:
             f.write(data_handler.header())
             f.writelines(
                 data_handler.separator.join(
-                    seg.__str__(data_handler) for seg in self.segments))
+                    seg.__str__(data_handler) for seg in self.segments
+                )
+            )
             f.write(data_handler.footer())
 
         # return back new object in case we are updating a list in place
@@ -121,7 +132,8 @@ class time_aligned_text(object):
             new_seg = time_aligned_text()
             new_seg.file_extension = self.file_extension
             new_seg.location = generate_segmented_file_name(
-                target_dir, self.location, iseg)
+                target_dir, self.location, iseg
+            )
             new_seg.segments = [seg]
             new_seg.write(new_seg.location)
 
