@@ -26,34 +26,40 @@ def ordinal_to_string(input_string):
     >>> ordinal_to_string("4th")
     'fourth'
     """
+
     def has_ordinal(input_string):
         " checks if input_string has ordinal "
-        return contains_digit(input_string) and (input_string[-2:] == "st"
-                                                 or input_string[-2:] == "nd"
-                                                 or input_string[-2:] == "rd"
-                                                 or input_string[-2:] == "th")
+        return contains_digit(input_string) and (
+            input_string[-2:] == "st"
+            or input_string[-2:] == "nd"
+            or input_string[-2:] == "rd"
+            or input_string[-2:] == "th"
+        )
 
     ret_str = input_string
 
     if has_ordinal(input_string):
-        ret_str = ((num2words.num2words(int(input_string[:-2]),
-                                        ordinal=True)).replace(",",
-                                                               "").replace(
-                                                                   "-", " "))
+        ret_str = (
+            (num2words.num2words(int(input_string[:-2]), ordinal=True))
+            .replace(",", "")
+            .replace("-", " ")
+        )
 
     return ret_str
 
 
 def format_dollars(dollar_string, dollars):
     " format dollar string "
-    return dollar_string + " dollars" if dollars and int(
-        dollars) != 1 else "one dollar"
+    return dollar_string + " dollars" if dollars and int(dollars) != 1 else "one dollar"
 
 
 def format_cents(cents_string, cents):
     " format cent string "
-    return ((" and {:} cents".format(cents_string) if int(cents) != 1 else
-             " and one cent") if (cents_string and cents) else "")
+    return (
+        (" and {:} cents".format(cents_string) if int(cents) != 1 else " and one cent")
+        if (cents_string and cents)
+        else ""
+    )
 
 
 def format_quantities(input_string):
@@ -61,8 +67,7 @@ def format_quantities(input_string):
 
     possible_quant = input_string[-1].upper() if input_string else ""
     quantity_dict = {"B": "billion", "M": "million", "K": "thousand"}
-    quant = quantity_dict[
-        possible_quant] if possible_quant in quantity_dict else ""
+    quant = quantity_dict[possible_quant] if possible_quant in quantity_dict else ""
 
     if quant:
         input_string = input_string[:-1]
@@ -73,19 +78,20 @@ def format_quantities(input_string):
 def format_dollars_and_cents(input_string):
     "formats de-formatted dollars and cents from dollars and cents string"
     # split into pieces
-    dollars, cents = (input_string.split(".")
-                      if "." in input_string else [input_string, None])
+    dollars, cents = (
+        input_string.split(".") if "." in input_string else [input_string, None]
+    )
 
     # format all as numbers
     dollar_words, cent_words = list(
         map(
             lambda num: num2words.num2words(int(num)) if num else None,
             [dollars, cents + "0" if (cents and len(cents) == 1) else cents],
-        ))
+        )
+    )
 
     # format the output
-    return format_dollars(dollar_words, dollars) + format_cents(
-        cent_words, cents)
+    return format_dollars(dollar_words, dollars) + format_cents(cent_words, cents)
 
 
 def dollars_to_string(input_string):
@@ -115,8 +121,7 @@ def dollars_to_string(input_string):
     if not quant:
         ret_str = format_dollars_and_cents(input_string)
     else:
-        ret_str = " ".join(
-            [num2words.num2words(float(input_string)), quant, "dollars"])
+        ret_str = " ".join([num2words.num2words(float(input_string)), quant, "dollars"])
 
     # remove minus signs
     ret_str = ret_str.replace("-", " ")
@@ -127,8 +132,9 @@ def dollars_to_string(input_string):
 def get_numbers_after_decicmal_point(input_string):
     " Format every number after decimal point "
     ret_str = ""
-    decimal = (input_string.split(".")[1].strip()
-               if len(input_string.split(".")) > 1 else "")
+    decimal = (
+        input_string.split(".")[1].strip() if len(input_string.split(".")) > 1 else ""
+    )
     if decimal:
         ret_str += " point"
         ret_str += " zero" * decimal.count("0")
@@ -148,8 +154,11 @@ def digits_to_string(input_string):
     """
     ret_str = input_string
     if input_string:
-        ret_str = (num2words.num2words(int(input_string.split(".")[0]))
-                   if input_string.split(".")[0] != "" else "")
+        ret_str = (
+            num2words.num2words(int(input_string.split(".")[0]))
+            if input_string.split(".")[0] != ""
+            else ""
+        )
         ret_str += get_numbers_after_decicmal_point(input_string)
 
     return ret_str.replace("-", " ")
@@ -173,14 +182,14 @@ def pluralize(substring):
 
     def is_multiple_of_ten(notten):
         "check for twenties, etc. but not 1-10, 100, 1000, etc."
-        return (len(notten) == 2 and notten != "00" and notten != "10"
-                and notten[-1] == "0")
+        return (
+            len(notten) == 2 and notten != "00" and notten != "10" and notten[-1] == "0"
+        )
 
     if is_multiple_of_ten(substring):
         ret_str = digits_to_string(substring)[:-1] + "ies"
     else:
-        ret_str = digits_to_string(substring) + ("es" if substring[-1] == "6"
-                                                 else "s")
+        ret_str = digits_to_string(substring) + ("es" if substring[-1] == "6" else "s")
     return ret_str
 
 
@@ -198,10 +207,11 @@ def plural_numbers_to_string(input_string):
     """
     input_string = "".join(_ for _ in input_string if _.isdigit())
 
-    ret_str = (" ".join(
-        (digits_to_string(input_string[:2]), pluralize(input_string[2:]))) if
-               (len(input_string) == 4
-                and input_string[-2:] != "00") else pluralize(input_string))
+    ret_str = (
+        " ".join((digits_to_string(input_string[:2]), pluralize(input_string[2:])))
+        if (len(input_string) == 4 and input_string[-2:] != "00")
+        else pluralize(input_string)
+    )
 
     return ret_str
 
