@@ -18,14 +18,14 @@ from asrtoolkit.file_utils.name_cleaners import basename, sanitize, strip_extens
 
 def clean_line(line):
     "clean up a line and test for empty values"
-    return clean_up(" ".join(
-        map(lambda val: str(val) if not pd.isnull(val) else "", line)))
+    return clean_up(
+        " ".join(map(lambda val: str(val) if not pd.isnull(val) else "", line))
+    )
 
 
 def dump_sheet(output_file, sheet):
     "dump a sheet from a list of spreadsheets into a file"
-    output_file.write("\n".join(
-        clean_line(line) for line in sheet if clean_line(line)))
+    output_file.write("\n".join(clean_line(line) for line in sheet if clean_line(line)))
 
 
 def extract_xlsx(filename, target_folder):
@@ -35,11 +35,9 @@ def extract_xlsx(filename, target_folder):
     working_excel_data_structure = pd.ExcelFile(filename)
     raw_name = sanitize(strip_extension(basename(filename)))
 
-    with open("".join([target_folder, "/", raw_name, ".txt"]),
-              "a+") as output_file:
+    with open("".join([target_folder, "/", raw_name, ".txt"]), "a+") as output_file:
         for sheet in working_excel_data_structure.sheet_names:
-            dump_sheet(output_file,
-                       working_excel_data_structure.parse(sheet).values)
+            dump_sheet(output_file, working_excel_data_structure.parse(sheet).values)
 
 
 def proc_input_dir_to_corpus(input_dir, output_dir):
@@ -48,15 +46,14 @@ def proc_input_dir_to_corpus(input_dir, output_dir):
     """
     os.makedirs(output_dir, exist_ok=True)
 
-    for spreadsheet in glob(input_dir + "/*.xlsx") + glob(input_dir +
-                                                          "/*.xls"):
+    for spreadsheet in glob(input_dir + "/*.xlsx") + glob(input_dir + "/*.xls"):
         extract_xlsx(spreadsheet, output_dir)
 
 
 def main():
     parser = argparse.ArgumentParser(
-        description=
-        "convert a folder of excel spreadsheets to a corpus of text files")
+        description="convert a folder of excel spreadsheets to a corpus of text files"
+    )
     parser.add_argument(
         "--input-folder",
         default="./",
