@@ -35,16 +35,17 @@ def sanitize(file_name, chars_to_replace="- ", silent=True):
     >>> sanitize("-asdflkj_ .tmp")
     '_asdflkj__.tmp'
     """
+
     def replace_char(input_char, file_name):
         " replace specific char if present "
         if input_char in file_name and not silent:
             print(
-                "replacing '{:}'s with underscores in sph file output - ".
-                format(c) +
-                "check to make sure your audio files and transcript files match"
+                "replacing '{:}'s with underscores in sph file output - ".format(c)
+                + "check to make sure your audio files and transcript files match"
             )
-        return os.path.join(os.path.dirname(file_name),
-                            basename(file_name).replace(c, "_"))
+        return os.path.join(
+            os.path.dirname(file_name), basename(file_name).replace(c, "_")
+        )
 
     for c in chars_to_replace:
         file_name = replace_char(c, file_name)
@@ -63,7 +64,10 @@ def generate_segmented_file_name(target_dir, file_name, iseg):
     """
     Take a target location, a current location, and a segment number and generate a target filename
     """
-    return sanitize_hyphens(target_dir + os.sep +
-                            basename(strip_extension(file_name)) +
-                            "_seg_{:05d}.".format(iseg) +
-                            file_name.split(".")[-1])
+    return sanitize_hyphens(
+        target_dir
+        + os.sep
+        + basename(strip_extension(file_name))
+        + "_seg_{:05d}.".format(iseg)
+        + file_name.split(".")[-1]
+    )
