@@ -21,12 +21,12 @@ def valid_input_file(file_name, valid_extensions=[]):
     True
     """
     return isfile(file_name) and get_extension(file_name) in (
-        valid_extensions if valid_extensions else VALID_EXTENSIONS)
+        valid_extensions if valid_extensions else VALID_EXTENSIONS
+    )
 
 
 def assign_if_valid(file_name):
     from asrtoolkit.data_structures.time_aligned_text import time_aligned_text
 
     " returns a time_aligned_text object if valid else None"
-    return time_aligned_text(file_name) if valid_input_file(
-        file_name) else None
+    return time_aligned_text(file_name) if valid_input_file(file_name) else None
